NaMaster: Data Fields

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

- All
- Variables

- a
- b
- c
- d
- e
- f
- h
- i
- l
- m
- n
- p
- s
- t
- w
- x
- y

Here is a list of all struct and union fields with links to the structures/unions they belong to:

### - a -

- a_mask : nmt_field , nmt_field_flat
- a_temp : nmt_field , nmt_field_flat
- alms : nmt_field , nmt_field_flat

### - b -

- beam : nmt_field , nmt_field_flat
- beam_prod : nmt_workspace
- bin : nmt_covar_workspace_flat , nmt_workspace , nmt_workspace_flat

### - c -

- coupling_matrix_binned : nmt_workspace , nmt_workspace_flat
- coupling_matrix_binned_gsl : nmt_workspace_flat
- coupling_matrix_perm : nmt_workspace , nmt_workspace_flat
- coupling_matrix_unbinned : nmt_workspace , nmt_workspace_flat
- cs : nmt_field , nmt_workspace

### - d -

- dell : nmt_flatsky_info
- Delta_phi : nmt_curvedsky_info
- Delta_theta : nmt_curvedsky_info

### - e -

- ell_0_list : nmt_binning_scheme_flat
- ell_f_list : nmt_binning_scheme_flat
- ell_list : nmt_binning_scheme
- ell_max : nmt_binning_scheme
- ell_min : nmt_flatsky_info
- ellcut_x : nmt_workspace_flat
- ellcut_y : nmt_workspace_flat

### - f -

- f_ell : nmt_binning_scheme
- fs : nmt_field_flat , nmt_workspace_flat

### - h -

- has_00 : nmt_master_calculator
- has_0s : nmt_master_calculator
- has_ss : nmt_master_calculator

### - i -

- i_dell : nmt_flatsky_info
- is_const : nmt_k_function
- is_healpix : nmt_curvedsky_info
- is_teb : nmt_workspace , nmt_workspace_flat

### - l -

- lite : nmt_field , nmt_field_flat
- lmax : nmt_covar_workspace , nmt_field , nmt_master_calculator , nmt_workspace , nmt_workspace_flat
- lmax_fields : nmt_workspace
- lmax_mask : nmt_master_calculator , nmt_workspace
- lmax_sht : nmt_curvedsky_info
- lx : nmt_flatsky_info
- ly : nmt_flatsky_info

### - m -

- maps : nmt_field , nmt_field_flat
- mask : nmt_field , nmt_field_flat
- mask_only : nmt_field , nmt_field_flat
- matrix_M : nmt_field , nmt_field_flat

### - n -

- n_bands : nmt_binning_scheme , nmt_binning_scheme_flat
- n_cells : nmt_workspace_flat
- n_ell : nmt_flatsky_info
- n_eq : nmt_curvedsky_info
- ncls : nmt_workspace , nmt_workspace_flat
- nell_list : nmt_binning_scheme
- nmaps : nmt_field , nmt_field_flat
- npcl : nmt_master_calculator
- npix : nmt_curvedsky_info , nmt_field , nmt_field_flat , nmt_flatsky_info
- npure_0s : nmt_master_calculator
- npure_ss : nmt_master_calculator
- ntemp : nmt_field , nmt_field_flat
- nx : nmt_curvedsky_info , nmt_flatsky_info
- nx_short : nmt_curvedsky_info
- ny : nmt_curvedsky_info , nmt_flatsky_info

### - p -

- pb1 : nmt_workspace_flat
- pb2 : nmt_workspace_flat
- pcl_masks : nmt_workspace
- pe1 : nmt_workspace_flat
- pe2 : nmt_workspace_flat
- phi0 : nmt_curvedsky_info
- pixsize : nmt_flatsky_info
- pure_any : nmt_master_calculator
- pure_b : nmt_field , nmt_field_flat
- pure_b1 : nmt_master_calculator
- pure_b2 : nmt_master_calculator
- pure_e : nmt_field , nmt_field_flat
- pure_e1 : nmt_master_calculator
- pure_e2 : nmt_master_calculator

### - s -

- s1 : nmt_master_calculator
- s2 : nmt_master_calculator
- spin : nmt_field , nmt_field_flat
- spl : nmt_k_function

### - t -

- temp : nmt_field , nmt_field_flat
- theta0 : nmt_curvedsky_info

### - w -

- w_list : nmt_binning_scheme

### - x -

- x0 : nmt_k_function
- xf : nmt_k_function
- xi00_1122 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi00_1221 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi02_1122 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi02_1221 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi22m_1122 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi22m_1221 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi22p_1122 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi22p_1221 : nmt_covar_workspace , nmt_covar_workspace_flat
- xi_00 : nmt_master_calculator
- xi_0s : nmt_master_calculator
- xi_mm : nmt_master_calculator
- xi_pp : nmt_master_calculator

### - y -

- y0 : nmt_k_function
- yf : nmt_k_function